@@ -1,7 +1,8 @@
 wetherill <- function(x,i){
     out <- list()
     if (x$format < 4) labels <- c('Pb207U235','Pb206U238')
-    else labels <- c('Pb207U235','Pb206U238','Pb204U238')
+    else if (x$format < 7) labels <- c('Pb207U235','Pb206U238','Pb204U238')
+    else labels <- c('Pb207U235','Pb206U238','Pb208Th232')
     if (x$format %in% c(1,3)){
         out$x <- x$x[i,labels]
         out$cov <- cor2cov2(x$x[i,'errPb207U235'],x$x[i,'errPb206U238'],x$x[i,'rhoXY'])
@@ -11,7 +12,6 @@ wetherill <- function(x,i){
         Pb206U238 <- 1/x$x[i,'U238Pb206']
         out$x <- c(Pb207U235,Pb206U238)
         J <- matrix(0,2,2)
-        E <- matrix(0,2,2)
         J[1,1] <- -Pb207U235/x$x[i,'U238Pb206']
         J[1,2] <- U238U235/x$x[i,'U238Pb206']
         J[2,1] <- -1/x$x[i,'U238Pb206']^2
@@ -29,7 +29,6 @@ wetherill <- function(x,i){
         Pb204U238 <- x$x[i,'Pb204Pb206']/x$x[i,'U238Pb206']
         out$x <- c(Pb207U235,Pb206U238,Pb204U238)
         J <- matrix(0,3,3)
-        E <- matrix(0,3,3)
         J[1,1] <- -Pb207U235/x$x[i,'U238Pb206']
         J[1,2] <- U238U235/x$x[i,'U238Pb206']
         J[2,1] <- -Pb206U238/x$x[i,'U238Pb206']
@@ -59,6 +58,29 @@ wetherill <- function(x,i){
         out$cov[2,1] <- out$cov[1,2]
         out$cov[3,1] <- out$cov[1,3]
         out$cov[3,2] <- out$cov[2,3]
+    } else if (x$format == 7){
+        out$x <- x$x[i,labels]
+        out$cov <- cor2cov3(x$x[i,'errPb207U235'],x$x[i,'errPb206U238'],
+                            x$x[i,'errPb208Th232'],x$x[i,'rhoXY'],
+                            x$x[i,'rhoXZ'],x$x[i,'rhoYZ'])
+    } else if (x$format == 8){
+        U238U235 <- iratio('U238U235')[1]
+        Pb207U235 <- U238U235*x$x[i,'Pb207Pb206']/x$x[i,'U238Pb206']
+        Pb206U238 <- 1/x$x[i,'U238Pb206']
+        Pb208Th232 <- x$x[i,'Pb208Pb206']/(x$x[i,'U238Pb206']*x$x[i,'Th232U238'])
+        out$x <- c(Pb207U235,Pb206U238,Pb208Th232)
+        J <- matrix(0,3,4)
+        J[1,1] <- -Pb207U235/x$x[i,'U238Pb206']
+        J[1,2] <- U238U235/x$x[i,'U238Pb206']
+        J[2,1] <- -Pb206U238/x$x[i,'U238Pb206']
+        J[3,1] <- -Pb208Th232/x$x[i,'U238Pb206']
+        J[3,3] <- 1/(x$x[i,'U238Pb206']*x$x[i,'Th232U238'])
+        J[3,4] <- -Pb208Th232/x$x[i,'Th232U238']
+        E <- cor2cov4(x$x[i,'errU238Pb206'],x$x[i,'errPb207Pb206'],
+                      x$x[i,'errPb208Pb206'],x$x[i,'errTh232U238'],
+                      x$x[i,'rhoXY'],x$x[i,'rhoXZ'],x$x[i,'rhoXW'],
+                      x$x[i,'rhoYZ'],x$x[i,'rhoYW'],x$x[i,'rhoZW'])
+        out$cov <- J %*% E %*% t(J)        
     }
     names(out$x) <- labels
     colnames(out$cov) <- labels
@@ -74,7 +96,6 @@ tera.wasserburg <- function(x,i){
         U238Pb206 <- 1/x$x[i,'Pb206U238']
         Pb207Pb206 <- x$x[i,'Pb207U235']/(x$x[i,'Pb206U238']*U238U235)
         J <- matrix(0,2,2)
-        E <- matrix(0,2,2)
         J[1,2] <- -1/x$x[i,'Pb206U238']^2
         J[2,1] <- 1/(x$x[i,'Pb206U238']*U238U235)
         J[2,2] <- -Pb207Pb206/x$x[i,'Pb206U238']
@@ -88,12 +109,11 @@ tera.wasserburg <- function(x,i){
         diag(out$cov) <- x$x[i,c('errU238Pb206','errPb207Pb206')]^2
         out$cov <-
             cor2cov2(x$x[i,'errU238Pb206'],x$x[i,'errPb207Pb206'],x$x[i,'rhoXY'])
-    } else if (x$format==3){
+    } else if (x$format == 3){
         labels <- c('U238Pb206','Pb207Pb206')
         U238Pb206 <- 1/x$x[i,'Pb206U238']
         out$x <- c(U238Pb206,x$x[i,'Pb207Pb206'])
         J <- matrix(0,2,2)
-        E <- matrix(0,2,2)
         E <- cor2cov2(x$x[i,'errPb206U238'],x$x[i,'errPb207Pb206'],x$x[i,'rhoYZ'])
         J[1,1] <- -U238Pb206^2
         J[2,2] <- 1
@@ -145,6 +165,33 @@ tera.wasserburg <- function(x,i){
         out$cov[2,1] <- out$cov[1,2]
         out$cov[3,1] <- out$cov[1,3]
         out$cov[3,2] <- out$cov[2,3]
+    } else if (x$format == 7){
+        labels <- c('U238Pb206','Pb207Pb206','Pb208Pb206')
+        U238U235 <- iratio('U238U235')[1]
+        U238Pb206 <- 1/x$x[i,'Pb206U238']
+        Pb207Pb206 <- x$x[i,'Pb207U235']/(x$x[i,'Pb206U238']*U238U235)
+        Pb208Pb206 <- x$x[i,'Pb208Th232']*x$x[i,'Th232U238']/x$x[i,'Pb206U238']
+        E <- cor2cov4(x$x[i,'errPb207U235'],x$x[i,'errPb206U238'],
+                      x$x[i,'errPb208Th232'],x$x[i,'errTh232U238'],
+                      x$x[i,'rhoXY'],x$x[i,'rhoXZ'],x$x[i,'rhoXW'],
+                      x$x[i,'rhoYZ'],x$x[i,'rhoYW'],x$x[i,'rhoZW'])
+        J <- matrix(0,3,4)
+        J[1,2] <- -U238Pb206/x$x[i,'Pb206U238']
+        J[2,1] <- 1/(x$x[i,'Pb206U238']*U238U235)
+        J[2,2] <- -Pb207Pb206/x$x[i,'Pb206U238']
+        J[3,2] <- -Pb208Pb206/x$x[i,'Pb206U238']
+        J[3,3] <- x$x[i,'Th232U238']/x$x[i,'Pb206U238']
+        J[3,4] <- x$x[i,'Pb208Th232']/x$x[i,'Pb206U238']
+        out$x <- c(U238Pb206,Pb207Pb206,Pb208Pb206)
+        out$cov <- J %*% E %*% t(J)
+    } else if (x$format == 8){
+        labels <- c('U238Pb206','Pb207Pb206','Pb208Pb206')
+        out$x <- x$x[i,c('U238Pb206','Pb207Pb206','Pb208Pb206')]
+        out$cov <- matrix(0,3,3)
+        diag(out$cov) <- x$x[i,c('errU238Pb206','errPb207Pb206','errPb208Pb206')]^2
+        out$cov <-
+            cor2cov3(x$x[i,'errU238Pb206'],x$x[i,'errPb207Pb206'],x$x[i,'errPb208Pb206'],
+                     x$x[i,'rhoXY'],x$x[i,'rhoXZ'],x$x[i,'rhoYZ'])
     }
     names(out$x) <- labels
     colnames(out$cov) <- labels
@@ -400,6 +447,30 @@ age_to_terawasserburg_ratios <- function(tt,st=0,exterr=FALSE,d=diseq()){
     colnames(out$cov) <- labels
     out
 }
+age_to_cottle_ratios <- function(tt,st=0,exterr=FALSE,d=diseq()){
+    out <- list()
+    labels <- c('Pb206U238','Pb208Th232')
+    l8 <- settings('lambda','U238')[1]
+    l2 <- settings('lambda','Th232')[1]
+    D <- wendt(tt=tt,d=d)
+    Pb6U8 <- exp(l8*tt)-1 + D$d2
+    Pb8Th2 <- exp(l2*tt)-1
+    out$x <- c(Pb6U8,Pb8Th2)
+    E <- matrix(0,3,3)
+    diag(E) <- c(st,lambda('U238')[2],lambda('Th232')[2])^2
+    J <- matrix(0,2,3)
+    J[1,1] <- l8*exp(l8*tt) + D$dd2dt
+    J[2,1] <- l2*exp(l2*tt)
+    if (exterr){
+        J[1,2] <- tt*exp(l8*tt) + D$dd2dl8
+        J[2,3] <- tt*exp(l2*tt)
+    }
+    out$cov <- J %*% E %*% t(J)
+    names(out$x) <- labels
+    rownames(out$cov) <- labels
+    colnames(out$cov) <- labels
+    out
+}
 
 age_to_Pb207U235_ratio <- function(tt,st=0,d=diseq()){
     ns <- length(tt)
@@ -493,6 +564,27 @@ age_to_Pb207Pb206_ratio <- function(tt,st=0,d=diseq()){
     }
     out
 }
+age_to_Pb208Th232_ratio <- function(tt,st=0){
+    ns <- length(tt)
+    if (ns>1){
+        out <- matrix(0,ns,2)
+        colnames(out) <- c('82','s[82]')
+        for (i in 1:ns){
+            if (length(st)<ns) sti <- st[1]
+            else sti <- st[i]
+            out[i,] <- age_to_Pb208Th232_ratio(tt[i],st=sti)
+        }
+    } else {
+        l2 <- lambda('Th232')[1]
+        R <- exp(l2*tt)-1
+        J <- l2*exp(l2*tt)
+        R.err <- abs(J*st)
+        out <- cbind(R,R.err)
+        colnames(out) <- c('82','s[82]')
+    }
+    out    
+}
+
 check.zero.UPb <- function(tt){
     smallnum <- 2*.Machine$double.neg.eps/lambda('U238')[1]
     if (length(tt)>1){
@@ -507,8 +599,9 @@ check.zero.UPb <- function(tt){
 
 get.Pb204U238.ratios <- function(x){
     labels <- c('Pb204U238','errPb204U238')
-    if (x$format < 4) stop('No 204Pb measurements available!')
-    else if (x$format %in% c(4,6)){
+    if (x$format %in% c(1,2,3,7,8)){
+        stop('No 204Pb measurements available!')
+    } else if (x$format %in% c(4,6)){
         out <- subset(x$x,select=labels)
     } else {
         Pb204U238 <- x$x[,'Pb204Pb206']/x$x[,'U238Pb206']
@@ -525,17 +618,16 @@ get.Pb207U235.ratios <- function(x,exterr=FALSE){
     out <- matrix(0,ns,2)
     labels <- c('Pb207U235','errPb207U235')
     colnames(out) <- labels
-    if (x$format %in% c(1,3,4,6)){
+    if (x$format %in% c(1,3,4,6,7)){
         out <- subset(x$x,select=labels)
-    } else if (x$format %in% c(2,5)){
+    } else if (x$format %in% c(2,5,8)){
         R <- iratio('U238U235')[1]
         sR <- iratio('U238U235')[2]
         X <- x$x[,'U238Pb206']
         sX <- x$x[,'errU238Pb206']
         Y <- x$x[,'Pb207Pb206']
         sY <- x$x[,'errPb207Pb206']
-        rhoXY <- x$x[,'rhoXY']
-        covXY <- rhoXY*sX*sY
+        covXY <- x$x[,'rhoXY']*sX*sY
         out[,'Pb207U235'] <- R*Y/X
         relerr2 <- (sX/X)^2 -2*covXY/(X*Y) + (sY/Y)^2
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
@@ -548,9 +640,9 @@ get.Pb206U238.ratios <- function(x){
     out <- matrix(0,ns,2)
     labels <- c('Pb206U238','errPb206U238')
     colnames(out) <- labels
-    if (x$format %in% c(1,3,4,6)){
+    if (x$format %in% c(1,3,4,6,7)){
         out <- subset(x$x,select=labels)
-    } else if (x$format %in% c(2,5)){
+    } else if (x$format %in% c(2,5,8)){
         out[,'Pb206U238'] <- 1/x$x[,'U238Pb206']
         out[,'errPb206U238'] <- out[,'Pb206U238']*
             x$x[,'errU238Pb206']/x$x[,'U238Pb206']
@@ -562,11 +654,11 @@ get.U238Pb206.ratios <- function(x){
     out <- matrix(0,ns,2)
     labels <- c('U238Pb206','errU238Pb206')
     colnames(out) <- labels
-    if (x$format %in% c(1,3,4,6)){
+    if (x$format %in% c(1,3,4,6,7)){
         out[,'U238Pb206'] <- 1/x$x[,'Pb206U238']
         out[,'errU238Pb206'] <- out[,'U238Pb206']*
             x$x[,'errPb206U238']/x$x[,'Pb206U238']
-    } else if (x$format %in% c(2,5)){
+    } else if (x$format %in% c(2,5,8)){
         out <- subset(x$x,select=labels)
     }
     out
@@ -576,7 +668,7 @@ get.Pb207Pb206.ratios <- function(x,exterr=FALSE){
     out <- matrix(0,ns,2)
     labels <- c('Pb207Pb206','errPb207Pb206')
     colnames(out) <- labels
-    if (x$format %in% c(1,4)){
+    if (x$format %in% c(1,4,7)){
         R <- iratio('U238U235')[1]
         sR <- iratio('U238U235')[2]
         X <- x$x[,'Pb207U235']
@@ -589,11 +681,35 @@ get.Pb207Pb206.ratios <- function(x,exterr=FALSE){
         relerr2 <- (sX/X)^2 - 2*covXY/(X*Y) + (sY/Y)^2
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
         out[,'errPb207Pb206'] <- sqrt(relerr2)*out[,'Pb207Pb206']
-    } else if (x$format %in% c(2,3,5,6)){
+    } else if (x$format %in% c(2,3,5,6,8)){
         out <- subset(x$x,select=labels)
     }
     out
 }
+get.Pb208Th232.ratios <- function(x){
+    ns <- length(x)
+    out <- matrix(0,ns,2)
+    labels <- c('Pb208Th232','errPb208Th232')
+    colnames(out) <- labels
+    if (x$format == 7){
+        out <- subset(x$x,select=labels)
+    } else if (x$format == 8){
+        out[,'Pb208Th232'] <- x$x[,'Pb208Pb206']/(x$x[,'U238Pb206']*x$x[,'Th232U238'])
+        J1 <- -out[,'Pb208Th232']/x$x[,'U238Pb206']
+        J2 <- 1/(x$x[,'U238Pb206']*x$x[,'Th232U238'])
+        J3 <- -out[,'Pb208Th232']/x$x[,'Th232U238']
+        E11 <- x$x[,'errU238Pb206']^2
+        E22 <- x$x[,'errPb208Pb206']^2
+        E33 <- x$x[,'errTh232U238']^2
+        E12 <- x$x[,'rhoXZ']*x$x[,'errU238Pb206']*x$x[,'errPb208Pb206']
+        E13 <- x$x[,'rhoXW']*x$x[,'errU238Pb206']*x$x[,'errTh232U238']
+        E23 <- x$x[,'rhoZW']*x$x[,'errPb208Pb206']*x$x[,'errTh232U238']
+        out[,'errPb208Th232'] <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12,E13,E23)
+    } else {
+        stop('Wrong input format: no Pb208 or Th232 present in this dataset.')
+    }
+    out
+}
 
 get.Pb207U235.age <- function(x,...){ UseMethod("get.Pb207U235.age",x) }
 get.Pb207U235.age.default <- function(x,sx=0,exterr=TRUE,d=diseq(),...){
@@ -611,7 +727,7 @@ get.Pb207U235.age.default <- function(x,sx=0,exterr=TRUE,d=diseq(),...){
         sl5 <- lambda('U235')[2]
         if (x>-1) t.75 <- log(1+x)/l5 else t.75 <- 0
         J <- matrix(0,1,2)
-        if (d$corr){
+        if (d$option%in%c(1,2)){
             dt <- 0.01/settings('lambda','U234')[1]
             search.range <- c(t.75-dt,t.75+dt)
             t.75 <- stats::optimize(diseq.75.misfit,interval=search.range,x=x,d=d)$minimum
@@ -664,7 +780,7 @@ get.Pb206U238.age.default <- function(x,sx=0,exterr=TRUE,d=diseq(),...){
         sl8 <- lambda('U238')[2]
         if (x>-1) t.init <- log(1+x)/l8 else t.init <- 0
         J <- matrix(0,1,2)
-        if (d$corr){
+        if (d$option%in%c(1,2)){
             t.68 <- tryCatch({
                 dt <- 0.01/settings('lambda','U234')[1]
                 search.range <- c(t.init-dt,t.init+dt)
@@ -778,6 +894,49 @@ get.Pb207Pb206.age.terawasserburg <- function(x,exterr=TRUE,...){
     get.Pb207Pb206.age(r76,sr76,exterr=exterr,d=x$d)
 }
 
+get.Pb208Th232.age <- function(x,...){ UseMethod("get.Pb208Th232.age",x) }
+get.Pb208Th232.age.default <- function(x,sx=0,exterr=TRUE,...){
+    ns <- length(x)
+    if (ns>1){
+        out <- matrix(0,ns,2)
+        colnames(out) <- c('t82','s[t82]')
+        for (i in 1:ns){
+            if (length(sx) < ns) sxi <- sx[1]
+            else sxi <- sx[i]
+            out[i,] <- get.Pb208Th232.age(x[i],sxi,exterr=exterr)
+        }
+    } else {
+        l2 <- lambda('Th232')[1]
+        sl2 <- lambda('Th232')[2]
+        if (x>-1) t.init <- log(1+x)/l2 else t.init <- 0
+        J <- matrix(0,1,2)
+        t.82 <- t.init
+        J[1,1] <- 1/(l2*(1+x))                       # dt/dx
+        if (exterr & x>-1) J[1,2] <- log(1+x)/l2^2   # dt/dl2
+        E <- matrix(0,2,2)
+        E[1,1] <- sx^2
+        E[2,2] <- sl2^2
+        st.82 <- sqrt(J %*% E %*% t(J))
+        out <- c(t.82,st.82)
+        names(out) <- c('t82','s[t82]')
+    }
+    out
+}
+get.Pb208Th232.age.UPb <- function(x,i=NA,exterr=TRUE,...){
+    r82 <- get.Pb208Th232.ratios(x)
+    if (is.na(i)){
+        ns <- length(x)
+        out <- matrix(0,ns,2)
+        for (j in 1:ns){
+            out[j,] <- get.Pb208Th232.age.UPb(x,i=j,exterr=exterr,...)
+        }
+    } else {
+        out <- get.Pb208Th232.age(r82[i,'Pb208Th232'],r82[i,'errPb208Th232'],
+                                 exterr=exterr,...)
+    }
+    out
+}
+
 # x is an object of class \code{UPb}
 # returns a matrix of 7/5, 6/8, 7/6
 # and concordia ages and their uncertainties.
@@ -785,6 +944,8 @@ UPb.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,conc=TRUE,show.p=FALSE,common.P
     if (common.Pb>0) X <- Pb0corr(x,option=common.Pb)
     else X <- x
     labels <- c('t.75','s[t.75]','t.68','s[t.68]','t.76','s[t.76]')
+    hasTh <- x$format%in%c(7,8)
+    if (hasTh) labels <- c(labels,'t.82','s[t.82]')
     if (conc) labels <- c(labels,'t.conc','s[t.conc]')
     if (conc & show.p) labels <- c(labels,'p[conc]')
     if (!is.na(i)){
@@ -795,6 +956,11 @@ UPb.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,conc=TRUE,show.p=FALSE,common.P
         t.68.out <- roundit(t.68[1],t.68[2],sigdig=sigdig)
         t.76.out <- roundit(t.76[1],t.76[2],sigdig=sigdig)
         out <- c(t.75.out,t.68.out,t.76.out)
+        if (hasTh){
+            t.82 <- get.Pb208Th232.age(X,i,exterr=exterr)
+            t.82.out <- roundit(t.82[1],t.82[2],sigdig=sigdig)
+            out <- c(out,t.82.out)
+        }
         if (conc){
             t.conc <- concordia.age(X,i,exterr=exterr)
             t.conc.out <- roundit(t.conc$age[1],t.conc$age[2],sigdig=sigdig)
@@ -821,44 +987,55 @@ UPb.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,conc=TRUE,show.p=FALSE,common.P
     out
 }
 
-filter.UPb.ages <- function(x,type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
-                            exterr=TRUE,common.Pb=0){
-    tt <- UPb.age(x,exterr=exterr,conc=(type==5),common.Pb=common.Pb)
-    do.76 <- tt[,'t.68'] > cutoff.76
+filter.UPb.ages <- function(x,type=4,cutoff.76=1100,exterr=TRUE,
+                            cutoff.disc=list(-15,5,TRUE),common.Pb=0){
+    tout <- UPb.age(x,exterr=exterr,conc=(type==5),common.Pb=common.Pb)
     if (any(is.na(cutoff.disc))){
-        is.concordant <- rep(TRUE,nrow(x))
+        is.concordant <- rep(TRUE,length(x))
     } else {
-        is.concordant <- concordant(tt,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc)
+        # apply cutoff filter before common Pb correction?
+        if (cutoff.disc[[3]] & common.Pb>0){
+            tin <- UPb.age(x,exterr=exterr,conc=(type==5),common.Pb=0)
+        } else { # apply cutoff filter after common Pb correction.
+            tin <- tout
+        }
+        is.concordant <- concordant(tin,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc)
         if (!any(is.concordant)){
             stop(paste0('There are no concordant grains in this sample.',
                         'Try adjusting the discordance limits OR ',
-                        'apply a common-Pb correction.'))
+                        'apply a common-Pb correction OR ',
+                        '(if you have already applied a common-Pb correction), ',
+                        'apply the discordance filter before the ',
+                        'common-Pb correction.'))
         }
     }
     out <- matrix(NA,length(x),2)
     if (type==1){
-        out[is.concordant,] <- tt[is.concordant,c('t.75','s[t.75]')]
+        out[is.concordant,] <- tout[is.concordant,c('t.75','s[t.75]')]
     } else if (type==2){
-        out[is.concordant,] <- tt[is.concordant,c('t.68','s[t.68]')]
+        out[is.concordant,] <- tout[is.concordant,c('t.68','s[t.68]')]
     } else if (type==3){
-        out[is.concordant,] <- tt[is.concordant,c('t.76','s[t.76]')]
+        out[is.concordant,] <- tout[is.concordant,c('t.76','s[t.76]')]
     } else if (type==4){
+        do.76 <- (tout[,'t.68']>cutoff.76)
         i.76 <- as.vector(which(do.76 & is.concordant))
         i.68 <- as.vector(which(!do.76 & is.concordant))
-        out[i.76,] <- tt[i.76,c('t.76','s[t.76]')]
-        out[i.68,] <- tt[i.68,c('t.68','s[t.68]')]
+        out[i.76,] <- tout[i.76,c('t.76','s[t.76]')]
+        out[i.68,] <- tout[i.68,c('t.68','s[t.68]')]
     } else if (type==5){
-        out[is.concordant,] <- tt[is.concordant,c('t.conc','s[t.conc]')]
+        out[is.concordant,] <- tout[is.concordant,c('t.conc','s[t.conc]')]
+    } else if (type==6){
+        out[is.concordant,] <- tout[is.concordant,c('t.82','s[t.82]')]
     }
     colnames(out) <- c('t','s[t]')
     out
 }
 
-concordant <- function(tt,cutoff.76=1100,cutoff.disc=c(-15,5)){
+concordant <- function(tt,cutoff.76=1100,cutoff.disc=list(-15,5,TRUE)){
     do.76 <- (tt[,'t.68'] > cutoff.76)
     disc.75.68 <- 100*(1-tt[,'t.75']/tt[,'t.68'])
     disc.68.76 <- 100*(1-tt[,'t.68']/tt[,'t.76'])
-    conc.75.68 <- !do.76 & (disc.75.68>cutoff.disc[1]) & (disc.75.68<cutoff.disc[2])
-    conc.68.76 <- do.76 & (disc.68.76>cutoff.disc[1]) & (disc.68.76<cutoff.disc[2])
+    conc.75.68 <- !do.76 & (disc.75.68>cutoff.disc[[1]]) & (disc.75.68<cutoff.disc[[2]])
+    conc.68.76 <- do.76 & (disc.68.76>cutoff.disc[[1]]) & (disc.68.76<cutoff.disc[[2]])
     conc.75.68 | conc.68.76
 }
