@@ -1,5 +1,6 @@
-#' Concordia diagram
+#' @title Concordia diagram
 #'
+#' @description
 #' Plots U-Pb data on Wetherill and Tera-Wasserburg concordia
 #' diagrams, calculate concordia ages and compositions, evaluates the
 #' equivalence of multiple
@@ -27,9 +28,9 @@
 #' samples plot near to, or overlap with, the concordia line. They
 #' represent the pinnacle of geochronological robustness. Samples that
 #' plot away from the concordia line but are aligned along a linear
-#' trend form an isochron (or `discordia' line) that can be used
-#' to infer the composition of the non-radiogenic
-#' (`common') lead or to constrain the timing of prior lead loss.
+#' trend form an isochron (or `discordia' line) that can be used to
+#' infer the composition of the non-radiogenic (`common') lead or to
+#' constrain the timing of prior lead loss.
 #'
 #' @param x an object of class \code{UPb}
 #' 
@@ -38,7 +39,21 @@
 #' @param alpha probability cutoff for the error ellipses and
 #'     confidence intervals
 #' 
-#' @param wetherill logical flag (\code{FALSE} for Tera-Wasserburg)
+#' @param type one of
+#'
+#' \enumerate{
+#'
+#' \item{Wetherill: \eqn{{}^{206}}Pb/\eqn{{}^{238}}U
+#' vs. \eqn{{}^{207}}Pb/\eqn{{}^{235}}U}
+#'
+#' \item{Tera-Wasserburg: \eqn{{}^{207}}Pb/\eqn{{}^{206}}Pb
+#' vs. \eqn{{}^{238}}U/\eqn{{}^{206}}Pb}
+#'
+#' \item{U-Th-Pb concordia: \eqn{{}^{208}}Pb/\eqn{{}^{232}}Th
+#' vs. \eqn{{}^{206}}Pb/\eqn{{}^{238}}U (only available if
+#' \code{x$format=7} or \code{x$format=8}})
+#'
+#' }
 #' 
 #' @param show.numbers logical flag (\code{TRUE} to show grain
 #'     numbers)
@@ -47,12 +62,30 @@
 #'     as different background colours within the error ellipses.
 #' 
 #' @param clabel label for the colour legend (only used if
-#'     \code{levels} is not \code{NA}.
+#'     \code{levels} is not \code{NA}).
 #' 
-#' @param ellipse.col a vector of two background colours for the error
-#'     ellipses. If \code{levels=NA}, then only the first colour is
-#'     used. If \code{levels} is a vector of numbers, then
-#'     \code{ellipse.col} is used to construct a colour ramp.
+#' @param ellipse.col
+#' Fill colour for the error ellipses. This can either be a single
+#' colour or multiple colours to form a colour ramp. Examples:
+#'
+#' \itemize{
+#'
+#' \item{a single colour: \code{rgb(0,1,0,0.5)}, \code{'#FF000080'},
+#' \code{'white'}, etc.}
+#'
+#' \item{multiple colours: \code{c(rbg(1,0,0,0.5)},
+#' \code{rgb(0,1,0,0.5))}, \code{c('#FF000080','#00FF0080')},
+#' \code{c('blue','red')}, \code{c('blue','yellow','red')}, etc.}
+#'
+#' \item{a colour palette: \code{rainbow(n=100)},
+#' \code{topo.colors(n=100,alpha=0.5)}, etc.}
+#'
+#' \item{a reversed palette: \code{rev(topo.colors(n=100,alpha=0.5))},
+#' etc.}
+#'
+#' \item{for empty ellipses, set \code{ellipse.col=NA}}
+#'
+#' }
 #' 
 #' @param concordia.col colour of the concordia line
 #' 
@@ -83,8 +116,8 @@
 #' @param sigdig number of significant digits for the
 #'     concordia/discordia age
 #' 
-#' @param common.Pb apply a common lead correction using one of three
-#'     methods:
+#' @param common.Pb
+#' apply a common lead correction using one of three methods:
 #'
 #' \code{1}: use the Stacey-Kramers two-stage model to infer the initial
 #' Pb-composition
@@ -95,11 +128,11 @@
 #' \code{settings('iratio','Pb207Pb206')} (if \code{x$format}<4) or
 #' \code{settings('iratio','Pb206Pb204')} and
 #' \code{settings('iratio','Pb207Pb204')} (if \code{x$format}>3)
-#' @param anchor control parameters to fix the intercept age or common
-#'     Pb composition of the discordia fit. This is a two-element
-#'     list.
+#' 
+#' @param anchor
+#' control parameters to fix the intercept age or common Pb
+#' composition of the discordia fit. This is a two-element list.
 #'
-
 #' \itemize{
 #'
 #' \item The first element is a boolean flag indicating whether the
@@ -111,9 +144,10 @@
 #' \code{NA}, then the common Pb composition is fixed at the values
 #' stored in \code{settings('iratio',...)}.
 #'
-#' item If the first element is \code{TRUE} and the second element is a
-#' number, then the discordia line is forced to intersect the
+#' \item If the first element is \code{TRUE} and the second element is
+#' a number, then the discordia line is forced to intersect the
 #' concordia line at an age equal to that number.
+#'
 #' }
 #'
 #' @param ticks either a scalar indicating the desired number of age
@@ -177,15 +211,13 @@
 #'
 #' \item{model}{ the fitting model (\code{=show.age-1}).}
 #'
-#' \item{x}{ a two-element vector with the upper and lower intercept
-#' ages (if \code{wetherill=TRUE}) or the lower intercept age and
-#' \eqn{^{207}}Pb/\eqn{^{206}}Pb intercept (if
-#' \code{wetherill=FALSE}).}
+#' \item{x}{ a vector with the upper and lower intercept
+#' ages (if \code{type=1}) or the lower intercept age and
+#' common Pb intercept(s) (if \code{type=2}).}
 #'
 #' \item{cov}{ the covariance matrix of the elements in \code{x}.}
 #'
-#' \item{err}{ a \code{[2 x 2]} or \code{[3 x 2]} matrix with the
-#' following rows:
+#' \item{err}{ a matrix with the following rows:
 #'
 #' \code{s}: the estimated standard deviation for \code{x}
 #'
@@ -221,26 +253,26 @@
 #' concordia(examples$UPb,show.age=2)
 #'
 #' dev.new()
-#' concordia(examples$UPb,wetherill=FALSE,
-#'           xlim=c(24.9,25.4),ylim=c(0.0508,0.0518),
-#'           ticks=249:254,exterr=TRUE)
+#' concordia(examples$UPb,type=1,xlim=c(24.9,25.4),
+#'           ylim=c(0.0508,0.0518),ticks=249:254,exterr=TRUE)
 #'
 #' dev.new()
-#' concordia(examples$UPb,wetherill=FALSE,show.age=2,anchor=list(TRUE,0))
+#' concordia(examples$UPb,type=2,show.age=2,anchor=list(TRUE,0))
 #'
 #' @references Ludwig, K.R., 1998. On the treatment of concordant
 #'     uranium-lead ages. Geochimica et Cosmochimica Acta, 62(4),
 #'     pp.665-676.
 #' @export
-concordia <- function(x=NULL,tlim=NULL,alpha=0.05,wetherill=TRUE,
+concordia <- function(x=NULL,tlim=NULL,alpha=0.05,type=1,
                       show.numbers=FALSE,levels=NA,clabel="",
                       ellipse.col=c("#00FF0080","#FF000080"),
                       concordia.col='darksalmon',exterr=FALSE,
                       show.age=0,sigdig=2,common.Pb=0,ticks=5,
                       anchor=list(FALSE,NA),hide=NULL,omit=NULL,
                       omit.col=NA,...){
+    wetherill <- (type==1) # TO BE REMOVED!
     if (is.null(x)){
-        emptyconcordia(tlim=tlim,alpha=alpha,wetherill=wetherill,exterr=exterr,
+        emptyconcordia(tlim=tlim,alpha=alpha,type=type,exterr=exterr,
                        concordia.col=concordia.col,ticks=ticks,...)
         return(invisible(NULL))
     }
@@ -250,19 +282,22 @@ concordia <- function(x=NULL,tlim=NULL,alpha=0.05,wetherill=TRUE,
     if (common.Pb<1) X <- x
     else X <- Pb0corr(x,option=common.Pb,omit=unique(c(hide,omit)))
     X2plot <- subset(X,subset=plotit)
-    lims <- prepare.concordia.line(X2plot,tlim=tlim,wetherill=wetherill,...)
+    lims <- prepare.concordia.line(X2plot,tlim=tlim,type=type,...)
     fit <- NULL
     if (show.age>1){
         x2calc <- subset(x,subset=calcit)
         fit <- concordia.intersection.ludwig(x2calc,wetherill=wetherill,exterr=exterr,
                                              alpha=alpha,model=(show.age-1),anchor=anchor)
-        discordia.line(fit,wetherill=wetherill,d=x$d)
+        discordia.line(fit,wetherill=(type==1),d=x$d)
         fit$n <- length(x2calc)
         graphics::title(discordia.title(fit,wetherill=wetherill,sigdig=sigdig))
     }
-    plot.concordia.line(X2plot,lims=lims,wetherill=wetherill,col=concordia.col,
+    plot.concordia.line(X2plot,lims=lims,type=type,col=concordia.col,
                         alpha=alpha,exterr=exterr,ticks=ticks)
-    y <- data2york(X,option=(2-1*wetherill))
+    if (type==1) y <- data2york(X,option=1)
+    else if (type==2) y <- data2york(X,option=2)
+    else if (x$format%in%c(7,8) & type==3) y <- data2york(X,option=5)
+    else stop('Concordia type incompatible with this input format.')
     scatterplot(y,alpha=alpha,show.numbers=show.numbers,
                 show.ellipses=1*(show.age!=3),levels=levels,
                 clabel=clabel,ellipse.col=ellipse.col,add=TRUE,
@@ -280,7 +315,7 @@ concordia <- function(x=NULL,tlim=NULL,alpha=0.05,wetherill=TRUE,
 }
 
 # helper function for plot.concordia
-plot.concordia.line <- function(x,lims,wetherill=TRUE,col='darksalmon',
+plot.concordia.line <- function(x,lims,type=1,col='darksalmon',
                                 alpha=0.05,exterr=TRUE,ticks=5){
     if (all(is.null(x$x))){
         m <- 0
@@ -291,11 +326,11 @@ plot.concordia.line <- function(x,lims,wetherill=TRUE,col='darksalmon',
         M <- min(1.2*lims$t[2],lims$t[2]+range.t/20)
     }
     nn <- 30 # number of segments into which the concordia line is divided
-    tt <- cseq(m,M,wetherill=wetherill,n=nn)
+    tt <- cseq(m,M,type=type,n=nn)
     conc <- matrix(0,nn,2)
     colnames(conc) <- c('x','y')
     for (i in 1:nn){ # build the concordia line
-        xy <- age_to_concordia_ratios(tt[i],wetherill=wetherill,exterr=exterr,d=x$d)
+        xy <- age_to_concordia_ratios(tt[i],type=type,exterr=exterr,d=x$d)
         if (exterr){ # show decay constant uncertainty
             if (i > 1) oldell <- ell
             ell <- ellipse(xy$x[1],xy$x[2],xy$cov,alpha=alpha)
@@ -308,10 +343,10 @@ plot.concordia.line <- function(x,lims,wetherill=TRUE,col='darksalmon',
         conc[i,] <- xy$x
     }
     if (length(ticks)<2)
-        ticks <- prettier(lims$t,wetherill=wetherill,n=ticks)
+        ticks <- prettier(lims$t,type=type,n=ticks)
     graphics::lines(conc[,'x'],conc[,'y'],col=col,lwd=2)
     for (i in 1:length(ticks)){
-        xy <- age_to_concordia_ratios(ticks[i],wetherill=wetherill,exterr=exterr,d=x$d)
+        xy <- age_to_concordia_ratios(ticks[i],type=type,exterr=exterr,d=x$d)
         if (exterr){ # show ticks as ellipse
             ell <- ellipse(xy$x[1],xy$x[2],xy$cov,alpha=alpha)
             graphics::polygon(ell,col='white')
@@ -319,27 +354,32 @@ plot.concordia.line <- function(x,lims,wetherill=TRUE,col='darksalmon',
             graphics::points(xy$x[1],xy$x[2],pch=21,bg='white')
         }
         pos <- 2
-        if ((wetherill  & diff(range(conc[,'x']))<0.05) |
-            (!wetherill & diff(range(conc[,'x']))<2.5) & exterr){ pos <- NULL }
+        if ((type%in%c(1,2)  & diff(range(conc[,'x']))<0.05) |
+            (type==2 & diff(range(conc[,'x']))<2.5) & exterr){ pos <- NULL }
         graphics::text(xy$x[1],xy$x[2],as.character(ticks[i]),pos=pos)
     }
     graphics::box()
 }
 # helper function for plot.concordia
-prepare.concordia.line <- function(x,tlim,wetherill=TRUE,...){
-    lims <- get.concordia.limits(x,tlim=tlim,wetherill=wetherill,...)
-    if (wetherill){
+prepare.concordia.line <- function(x,tlim,type=1,...){
+    lims <- get.concordia.limits(x,tlim=tlim,type=type,...)
+    if (type==1){
         x.lab <- expression(paste(""^"207","Pb/"^"235","U"))
         y.lab <- expression(paste(""^"206","Pb/"^"238","U"))
-    } else {
+    } else if (type==2){
         x.lab <- expression(paste(""^"238","U/"^"206","Pb"))
         y.lab <- expression(paste(""^"207","Pb/"^"206","Pb"))
+    } else if (x$format>6 & type==3){
+        x.lab <- expression(paste(""^"206","Pb/"^"238","U"))
+        y.lab <- expression(paste(""^"208","Pb/"^"232","Th"))
+    } else {
+        stop('Incorrect input format.')
     }
     graphics::plot(lims$x,lims$y,type='n',xlab=x.lab,ylab=y.lab,bty='n',...)
     lims
 }
-cseq <- function(m,M,wetherill=TRUE,n=50){
-    if (wetherill){
+cseq <- function(m,M,type=1,n=50){
+    if (type%in%c(1,2)){
         return(seq(m,M,length.out=n))
     }
     if (m>0){
@@ -350,17 +390,17 @@ cseq <- function(m,M,wetherill=TRUE,n=50){
     out[out<=0] <- min(out[out>0])/10
     out
 }
-prettier <- function(x,wetherill=TRUE,n=5){
+prettier <- function(x,type=1,n=5){
     pilot <- pretty(x,n=n)
-    if (wetherill){
+    if (type%in%c(1,3)){
         return(pilot)
     }
     m <- min(x)
     M <- max(x)
-    if (M/m < 50){ # linear spacing if spanning less than 1 order of magnitude
+    if (M/m<50){ # linear spacing if TW spans less than 1 order of magnitude
         out <- pilot
-    } else { # log spaced if spanning more than 1 order of magnitude
-        out <- cseq(m,M,wetherill=wetherill,n=n)
+    } else { # log spacing if TW spans more than 1 order of magnitude
+        out <- cseq(m,M,type=type,n=n)
         init <- out
         out[1] <- pilot[1]
         out[n] <- utils::tail(pilot,1)
@@ -371,11 +411,17 @@ prettier <- function(x,wetherill=TRUE,n=5){
     out[out<=0] <- min(out[out>0])/2
     out
 }
-age_to_concordia_ratios <- function(tt,wetherill=TRUE,exterr=FALSE,d=diseq()){
-    if (wetherill) return(age_to_wetherill_ratios(tt,exterr=exterr,d=d))
-    else return(age_to_terawasserburg_ratios(tt,exterr=exterr,d=d))
+age_to_concordia_ratios <- function(tt,type=1,exterr=FALSE,d=diseq()){
+    if (type==1)
+        return(age_to_wetherill_ratios(tt,exterr=exterr,d=d))
+    else if (type==2)
+        return(age_to_terawasserburg_ratios(tt,exterr=exterr,d=d))
+    else if (type==3)
+        return(age_to_cottle_ratios(tt,exterr=exterr))
+    else
+        stop('Invalid concordia type.')
 }
-get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
+get.concordia.limits <- function(x,tlim=NULL,type=1,...){
     out <- list()
     args <- list(...)
     xset <- ('xlim' %in% names(args))
@@ -397,10 +443,10 @@ get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
     if (is.null(tlim)) out$t <- c(0,0)
     else out$t <- tlim
     nse <- 3 # number of standard errors used for buffer
-    if (!is.null(tlim) && wetherill){
+    if (!is.null(tlim) && type==1){
         if (!xset) out$x <- age_to_Pb207U235_ratio(tlim,d=x$d)[,'75']
         if (!yset) out$y <- age_to_Pb206U238_ratio(tlim,d=x$d)[,'68']
-    } else if (!is.null(tlim) && !wetherill){
+    } else if (!is.null(tlim) && type==2){
         if (tlim[1] <= 0){
             U238Pb206 <- get.U238Pb206.ratios(x)
             if (xset) maxx <- out$x[2]
@@ -409,7 +455,10 @@ get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
         }
         if (!xset) out$x <- age_to_U238Pb206_ratio(out$t,d=x$d)[,'86']
         if (!yset) out$y <- age_to_Pb207Pb206_ratio(out$t,d=x$d)[,'76']
-    } else if (is.null(tlim) && wetherill) {
+    } else if (!is.null(tlim) && type==3){
+        if (!xset) out$x <- age_to_Pb206U238_ratio(tlim,d=x$d)[,'68']
+        if (!yset) out$y <- age_to_Pb208Th232_ratio(tlim)[,'82']
+    } else if (is.null(tlim) && type==1) {
         if (!xset){
             Pb207U235 <- get.Pb207U235.ratios(x)
             minx <- min(Pb207U235[,1]-nse*Pb207U235[,2],na.rm=TRUE)
@@ -432,7 +481,7 @@ get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
         }
         out$x <- c(minx,maxx)
         out$y <- c(miny,maxy)
-    } else if (is.null(tlim) && !wetherill){
+    } else if (is.null(tlim) && type==2){
         U238Pb206 <- get.U238Pb206.ratios(x)
         Pb207Pb206 <- get.Pb207Pb206.ratios(x)
         if (!xset){
@@ -445,8 +494,33 @@ get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
         }
         out$t[1] <- get.Pb206U238.age(1/maxx,d=x$d)[1]
         out$t[2] <- get.Pb207Pb206.age(maxy,d=x$d)[1]
-        if (!xset) minx <- min(minx,age_to_U238Pb206_ratio(out$t[2],d=x$d)[,'86'])
-        if (!yset) miny <- min(miny,age_to_Pb207Pb206_ratio(out$t[1],d=x$d)[,'76'])
+        if (!xset)
+            minx <- min(minx,age_to_U238Pb206_ratio(out$t[2],d=x$d)[,'86'])
+        if (!yset)
+            miny <- min(miny,age_to_Pb207Pb206_ratio(out$t[1],d=x$d)[,'76'])
+        out$x <- c(minx,maxx)
+        out$y <- c(miny,maxy)
+    } else if (is.null(tlim) && type==3){
+        if (!xset){
+            Pb206U238 <- get.Pb206U238.ratios(x)
+            minx <- min(Pb206U238[,1]-nse*Pb206U238[,2],na.rm=TRUE)
+            maxx <- max(Pb206U238[,1]+nse*Pb206U238[,2],na.rm=TRUE)
+        }
+        if (!yset){
+            Pb208Th232 <- get.Pb208Th232.ratios(x)
+            miny <- min(Pb208Th232[,1]-nse*Pb208Th232[,2],na.rm=TRUE)
+            maxy <- max(Pb208Th232[,1]+nse*Pb208Th232[,2],na.rm=TRUE)
+        }
+        out$t[1] <- get.Pb206U238.age(minx,d=x$d)[1]
+        out$t[2] <- get.Pb208Th232.age(maxy)[1]
+        if (!xset){
+            minx <- min(minx,age_to_Pb206U238_ratio(out$t[1],d=x$d)[,'68'])
+            maxx <- max(maxx,age_to_Pb206U238_ratio(out$t[2],d=x$d)[,'68'])
+        }
+        if (!yset){
+            miny <- min(miny,age_to_Pb208Th232_ratio(out$t[1])[,'82'])
+            maxy <- max(maxy,age_to_Pb208Th232_ratio(out$t[2])[,'82'])
+        }
         out$x <- c(minx,maxx)
         out$y <- c(miny,maxy)
     }
@@ -615,23 +689,35 @@ get.concordia.SS <- function(x,covmat){
     x %*% solve(covmat) %*% t(x)
 }
 
-emptyconcordia <- function(tlim=NULL,alpha=0.05,wetherill=TRUE,exterr=TRUE,
+emptyconcordia <- function(tlim=NULL,alpha=0.05,type=1,exterr=TRUE,
                            concordia.col='darksalmon',ticks=5,...){
-    if (is.null(tlim) && wetherill) tlim <- c(1,3500)
+    if (is.null(tlim) && type%in%c(1,3)) tlim <- c(1,3500)
     else if (is.null(tlim)) tlim <- c(100,3500)
     dat <- list()
     class(dat) <- 'UPb'
     dat$d <- diseq()
-    if (wetherill){
-        dat$x <- rbind(c(age_to_Pb207U235_ratio(tlim[1]),age_to_Pb206U238_ratio(tlim[1]),0),
-                       c(age_to_Pb207U235_ratio(tlim[1]),age_to_Pb206U238_ratio(tlim[1]),0))
+    if (type==1){
+        dat$x <- rbind(c(age_to_Pb207U235_ratio(tlim[1]),0,
+                         age_to_Pb206U238_ratio(tlim[1]),0,0),
+                       c(age_to_Pb207U235_ratio(tlim[2]),0,
+                         age_to_Pb206U238_ratio(tlim[2]),0,0))
         dat$format <- 1
-    } else {
-        dat$x <- rbind(c(age_to_U238Pb206_ratio(tlim[1]),age_to_Pb207Pb206_ratio(tlim[1])),
-                       c(age_to_U238Pb206_ratio(tlim[1]),age_to_Pb207Pb206_ratio(tlim[1])))
+    } else if (type==2){
+        dat$x <- rbind(c(age_to_U238Pb206_ratio(tlim[1]),0,
+                         age_to_Pb207Pb206_ratio(tlim[1]),0,0),
+                       c(age_to_U238Pb206_ratio(tlim[2]),0,
+                         age_to_Pb207Pb206_ratio(tlim[2]),0,0))
         dat$format <- 2
+    } else if (type==3){
+        dat$x <- rbind(c(0,0,age_to_Pb206U238_ratio(tlim[1]),0,
+                         age_to_Pb208Th232_ratio(tlim[1]),0,rep(0,8)),
+                       c(0,0,age_to_Pb206U238_ratio(tlim[2]),0,
+                         age_to_Pb208Th232_ratio(tlim[2]),0,rep(0,8)))
+        dat$format <- 7
+    } else {
+        stop('Invalid concordia type.')
     }
-    lims <- prepare.concordia.line(x=dat,tlim=tlim,wetherill=wetherill,...)
-    plot.concordia.line(x=dat,lims=lims,wetherill=wetherill,
-                        col=concordia.col,alpha=alpha,exterr=exterr,ticks=ticks)
+    lims <- prepare.concordia.line(x=dat,tlim=tlim,type=type,...)
+    plot.concordia.line(x=dat,lims=lims,type=type,col=concordia.col,
+                        alpha=alpha,exterr=exterr,ticks=ticks)
 }
