@@ -1,5 +1,6 @@
-#' Read geochronology data
+#' @title Read geochronology data
 #'
+#' @description
 #' Cast a \code{.csv} file or a matrix into one of \code{IsoplotR}'s
 #' data classes
 #'
@@ -176,15 +177,13 @@
 #' 
 #' }
 #'
-#' @param U48 the initial \eqn{^{234}}U/\eqn{^{238}}U-activity ratio
-#' @param Th0U8 the initial \eqn{^{230}}Th/\eqn{^{238}}U-activity ratio
-#' @param Ra6U8 the initial \eqn{^{226}}Ra/\eqn{^{238}}U-activity ratio
-#' @param Pa1U5 the initial \eqn{^{231}}Pa/\eqn{^{235}}U-activity ratio
+#' @param d an object of class \code{\link{diseq}}.
 #' 
 #' @param Th02 2-element vector with the assumed initial
 #'     \eqn{^{230}}Th/\eqn{^{232}}Th-ratio of the detritus and its
-#'     standard error. Only used if \code{isochron==FALSE} and
-#'     \code{detritus==2} 
+#'     standard error. Only used if \code{isochron=FALSE} and
+#'     \code{detritus=2}
+#' 
 #' @param Th02U48 9-element vector with the measured composition of
 #'     the detritus, containing \code{X=0/8}, \code{sX}, \code{Y=2/8},
 #'     \code{sY}, \code{Z=4/8}, \code{sZ}, \code{rXY}, \code{rXZ},
@@ -241,31 +240,25 @@
 read.data <- function(x,...){ UseMethod("read.data",x) }
 #' @rdname read.data
 #' @export
-read.data.default <- function(x,method='U-Pb',format=1,ierr=1,
-                              U48=1,Th0U8=1,Ra6U8=1,Pa1U5=1,
+read.data.default <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
                               Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
     X <- as.matrix(utils::read.table(x,sep=',',...))
-    read.data.matrix(X,method=method,format=format,ierr=ierr,
-                     U48=U48,Th0U8=Th0U8,Ra6U8=Ra6U8,Pa1U5=Pa1U5,
+    read.data.matrix(X,method=method,format=format,ierr=ierr,d=d,
                      Th02=Th02,Th02U48=Th02U48)
 }
 #' @rdname read.data
 #' @export
-read.data.data.frame <- function(x,method='U-Pb',format=1,ierr=1,
-                                 U48=1,Th0U8=1,Ra6U8=1,Pa1U5=1,
+read.data.data.frame <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
                                  Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
-    read.data.matrix(as.matrix(x),method=method,format=format,ierr=ierr,
-                     U48=U48,Th0U8=Th0U8,Ra6U8=Ra6U8,Pa1U5=Pa1U5,
-                     Th02=Th02,Th02U48=Th02U48,...)
+    read.data.matrix(as.matrix(x),method=method,format=format,
+                     ierr=ierr,d=d,Th02=Th02,Th02U48=Th02U48,...)
 }
 #' @rdname read.data
 #' @export
-read.data.matrix <- function(x,method='U-Pb',format=1,ierr=1,
-                             U48=1,Th0U8=1,Ra6U8=1,Pa1U5=1,
+read.data.matrix <- function(x,method='U-Pb',format=1,ierr=1,d=diseq(),
                              Th02=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0),...){
     if (identical(method,'U-Pb')){
-        out <- as.UPb(x,format=format,ierr=ierr,
-                      U48=U48,Th0U8=Th0U8,Ra6U8=Ra6U8,Pa1U5=Pa1U5)
+        out <- as.UPb(x,format=format,ierr=ierr,d=d)
     } else if (identical(method,'Pb-Pb')){
         out <- as.PbPb(x,format=format,ierr=ierr)
     } else if (identical(method,'Ar-Ar')){
@@ -294,12 +287,12 @@ read.data.matrix <- function(x,method='U-Pb',format=1,ierr=1,
     out
 }
 
-as.UPb <- function(x,format=3,ierr=1,U48=1,Th0U8=1,Ra6U8=1,Pa1U5=1){
+as.UPb <- function(x,format=3,ierr=1,d=diseq()){
     out <- list()
     class(out) <- "UPb"
     out$x <- NA
     out$format <- format
-    out$d <- diseq(U48=U48,Th0U8=Th0U8,Ra6U8=Ra6U8,Pa1U5=Pa1U5)
+    out$d <- d
     nc <- ncol(x)
     nr <- nrow(x)
     if (is.numeric(x)) X <- x
@@ -352,6 +345,20 @@ as.UPb <- function(x,format=3,ierr=1,U48=1,Th0U8=1,Ra6U8=1,Pa1U5=1){
                     'Pb207Pb206','errPb207Pb206',
                     'Pb204Pb207','errPb204Pb207',
                     'Pb204Pb206','errPb204Pb206')
+    } else if (format==7 & nc>7){
+        cnames <- c('Pb207U235','errPb207U235',
+                    'Pb206U238','errPb206U238',
+                    'Pb208Th232','errPb208Th232',
+                    'Th232U238','errTh232U238',
+                    'rhoXY','rhoXZ','rhoXW',
+                    'rhoYZ','rhoYW','rhoZW')
+    } else if (format==8 & nc>7){
+        cnames <- c('U238Pb206','errU238Pb206',
+                    'Pb207Pb206','errPb207Pb206',
+                    'Pb208Pb206','errPb208Pb206',
+                    'Th232U238','errTh232U238',
+                    'rhoXY','rhoXZ','rhoXW',
+                    'rhoYZ','rhoYW','rhoZW')
     }
     out$x <- subset(X,select=1:length(cnames))
     colnames(out$x) <- cnames
@@ -466,7 +473,7 @@ as.ArAr <- function(x,format=3,ierr=1){
     X <- shiny2matrix(x,bi,nr,nc)
     X <- errconvert(X,gc='Ar-Ar',format=format,ierr=ierr)
     if (format==3 & nc>6){
-        if (nc==7){
+        if (nc>7){
             out$x <- subset(X,select=1:7)
         } else {
             ns <- nr-bi+1 # number of samples
@@ -774,6 +781,7 @@ getErrCols <- function(gc,format=NA,ierr=1){
     UPb12 = (gc=='U-Pb' && format%in%(1:2))
     UPb345 = (gc=='U-Pb' && format%in%(3:5))
     UPb6 = (gc=='U-Pb' && format==6)
+    UPb78 = (gc=='U-Pb' && format%in%(7:8))
     PbPb12 = (gc=='Pb-Pb' && format%in%(1:2))
     PbPb3 = (gc=='Pb-Pb' && format==3)
     ArAr12 = (gc=='Ar-Ar' && format%in%(1:2))
@@ -793,6 +801,8 @@ getErrCols <- function(gc,format=NA,ierr=1){
         cols = c(2,4)
     } else if (UPb345 | PbPb3 | ArAr3 | KCa1 | PD1 | UThHe | ThU12){
         cols = c(2,4,6)
+    } else if (UPb78){
+        cols = seq(from=2,to=8,by=2)
     } else if (UPb6){
         cols = seq(from=2,to=12,by=2)
     } else if (radial || average){
