@@ -1,11 +1,12 @@
+#' @title
 #' Visualise heteroscedastic data on a radial plot
-#'
+#' 
+#' @description
 #' Implementation of a graphical device developed by Rex Galbraith to
 #' display several estimates of the same quantity that have different
 #' standard errors.
-#'
+#' 
 #' @details
-#'
 #' The radial plot (Galbraith, 1988, 1990) is a graphical device that
 #' was specifically designed to display heteroscedastic data, and is
 #' constructed as follows.  Consider a set of dates
@@ -29,8 +30,8 @@
 #' further towards the right. Thus, radial plots allow the observer to
 #' assess both the magnitude and the precision of quantitative data in
 #' one glance.
-#'
-#' @param x Either an \code{[n x 2]} matix of (transformed) values z
+#' 
+#' @param x Either an \code{[nx2]} matix of (transformed) values z
 #'     and their standard errors s
 #'
 #' OR
@@ -53,10 +54,28 @@
 #' @param levels a vector with additional values to be displayed as
 #'     different background colours of the plot symbols.
 #' @param clabel label of the colour legend
-#' @param bg a vector of two background colours for the plot symbols.
-#'     If \code{levels=NA}, then only the first colour is used. If
-#'     \code{levels} is a vector of numbers, then \code{bg} is used to
-#'     construct a colour ramp.
+#' @param bg Fill colour for the plot symbols. This can
+#'     either be a single colour or multiple colours to form a colour
+#'     ramp (to be used if \code{levels!=NA}):
+#'
+#' \itemize{
+#'
+#' \item{a single colour: \code{rgb(0,1,0,0.5)}, \code{'#FF000080'},
+#' \code{'white'}, etc.}
+#'
+#' \item{multiple colours: \code{c(rbg(1,0,0,0.5)},
+#' \code{rgb(0,1,0,0.5))}, \code{c('#FF000080','#00FF0080')},
+#' \code{c('blue','red')}, \code{c('blue','yellow','red')}, etc.}
+#'
+#' \item{a colour palette: \code{rainbow(n=100)},
+#' \code{topo.colors(n=100,alpha=0.5)}, etc.}
+#'
+#' \item{a reversed palette: \code{rev(topo.colors(n=100,alpha=0.5))},
+#' etc.}
+#'
+#' \item{for plot symbols, set \code{bg=NA}}
+#'
+#' }
 #' @param col text colour to be used if \code{show.numbers=TRUE}
 #' @param title add a title to the plot?
 #' @param k number of peaks to fit using the finite mixture models of
@@ -97,7 +116,6 @@
 #'
 #' dev.new()
 #' radialplot(examples$LudwigMixture,k='min')
-#'
 #' @rdname radialplot
 #' @export
 radialplot <- function(x,...){ UseMethod("radialplot",x) }
@@ -128,7 +146,7 @@ radialplot.default <- function(x,from=NA,to=NA,t0=NA,
     colourbar(z=levels[calcit],col=bg,clabel=clabel)
     if (title)
         title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
-                           units=units,n=nrow(x2calc)))
+                           units=units,ntit=get.ntit(x2calc[,1])))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -165,7 +183,7 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
     colourbar(z=levels[calcit],col=bg,clabel=clabel)
     if (title)
         title(radial.title(x2calc,sigdig=sigdig,alpha=alpha,
-                           units='Ma',n=length(x2calc)))
+                           units='Ma',ntit=get.ntit(x2calc$x[,1])))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -180,14 +198,21 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
 #'     \eqn{^{206}}Pb/\eqn{^{238}}U and above which the
 #'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age is used. This parameter is
 #'     only used if \code{type=4}.
-#' @param cutoff.disc two element vector with the maximum and minimum
-#'     percentage discordance allowed between the
-#'     \eqn{^{207}}Pb/\eqn{^{235}}U and \eqn{^{206}}Pb/\eqn{^{238}}U
-#'     age (if \eqn{^{206}}Pb/\eqn{^{238}}U < \code{cutoff.76}) or
-#'     between the \eqn{^{206}}Pb/\eqn{^{238}}U and
-#'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age (if
-#'     \eqn{^{206}}Pb/\eqn{^{238}}U > \code{cutoff.76}).  Set
-#'     \code{cutoff.disc=NA} if you do not want to use this filter.
+#' @param cutoff.disc discordance cutoff filter. This is a three
+#'     element list.
+#'
+#' The first two items contain the minimum (negative) and maximum
+#' (positive) percentage discordance allowed between the
+#' \eqn{^{207}}Pb/\eqn{^{235}}U and \eqn{^{206}}Pb/\eqn{^{238}}U age
+#' (if \eqn{^{206}}Pb/\eqn{^{238}}U < \code{cutoff.76}) or between the
+#' \eqn{^{206}}Pb/\eqn{^{238}}U and \eqn{^{207}}Pb/\eqn{^{206}}Pb age
+#' (if \eqn{^{206}}Pb/\eqn{^{238}}U > \code{cutoff.76}).
+#'
+#' The third item is a boolean flag that controls whether the
+#' discordance filter should be applied before (\code{TRUE}) or after
+#' (\code{FALSE}) the common-Pb correction.
+#'
+#' Set \code{cutoff.disc=NA} to turn off this filter.
 #' @param common.Pb apply a common lead correction using one of three
 #'     methods:
 #'
@@ -204,7 +229,7 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
 #' @export
 radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',type=4,
-                           cutoff.76=1100,cutoff.disc=c(-15,5),
+                           cutoff.76=1100,cutoff.disc=list(-15,5,TRUE),
                            show.numbers=FALSE,pch=21,
                            levels=NA,clabel="",bg=c("yellow","red"),
                            col='black',markers=NULL,k=0,exterr=TRUE,
@@ -366,7 +391,6 @@ radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
 #' \code{3}: correct the data using the measured present day
 #' \eqn{^{230}}Th/\eqn{^{238}}U, \eqn{^{232}}Th/\eqn{^{238}}U and
 #' \eqn{^{234}}U/\eqn{^{238}}U-ratios in the detritus.
-#'
 #' @rdname radialplot
 #' @export
 radialplot.ThU <- function(x,from=NA,to=NA,t0=NA,
@@ -753,13 +777,14 @@ iatt <- function(z,zeta,rhoD){
 }
 
 # this would be much easier in unicode but that doesn't render in PDF:
-radial.title <- function(x,sigdig=2,alpha=0.05,units='',n=length(x),...){
+radial.title <- function(x,sigdig=2,alpha=0.05,units='',
+                         ntit=paste0('n=',length(x)),...){
     fit <- central(x,alpha=alpha)
     rounded.age <- roundit(fit$age[1],fit$age[2:3],sigdig=sigdig)
     rounded.disp <- roundit(100*fit$disp[1],100*fit$disp[2:3],sigdig=sigdig)
-    line1 <- substitute('central age ='~a%+-%b~'|'~c~d~'(n='*n*')',
+    line1 <- substitute('central age ='~a%+-%b~'|'~c~d~'('*n*')',
                         list(a=rounded.age[1],b=rounded.age[2],
-                             c=rounded.age[3],d=units,n=n))
+                             c=rounded.age[3],d=units,n=ntit))
     line2 <- substitute('MSWD ='~a*', p('*chi^2*') ='~b,
                         list(a=signif(fit$mswd,sigdig),
                              b=signif(fit$p.value,sigdig)))
