@@ -1,5 +1,7 @@
+#' @title
 #' Linear regression of X,Y-variables with correlated errors
 #'
+#' @description
 #' Implements the unified regression algorithm of York et al. (2004)
 #' which, although based on least squares, yields results that are
 #' consistent with maximum likelihood estimates of Titterington and
@@ -44,11 +46,14 @@
 #'     degrees of freedom}
 #'
 #'     }
+#' 
 #' @seealso \code{\link{data2york}}, \code{\link{titterington}},
 #'     \code{\link{isochron}}, \code{\link{ludwig}}
-#' @references Titterington, D.M. and Halliday, A.N., 1979. On the
-#'     fitting of parallel isochrons and the method of maximum
-#'     likelihood. Chemical Geology, 26(3), pp.183-195.
+#' 
+#' @references
+#' Titterington, D.M. and Halliday, A.N., 1979. On the fitting of
+#' parallel isochrons and the method of maximum likelihood. Chemical
+#' Geology, 26(3), pp.183-195.
 #'
 #' York, Derek, et al., 2004. Unified equations for the slope,
 #' intercept, and standard errors of the best straight line.  American
@@ -162,11 +167,12 @@ get.york.xy <- function(x,a,b){
     out
 }
 
-#' Prepare geochronological data for York regression
+#' @title Prepare geochronological data for York regression
 #'
-#' Takes geochronology data as input and produces a
-#' five-column table as output, which can be used
-#' for York regression.
+#' @description
+#' Takes geochronology data as input and produces a five-column table
+#' with the variables, their uncertainties and error correlations as
+#' output. These can subsequently be used for York regression.
 #'
 #' @param x a five or six column matrix OR an object of class
 #'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{ThU}, \code{UThHe},
@@ -175,23 +181,25 @@ get.york.xy <- function(x,a,b){
 #'     \code{read.data(...)} function
 #' @param format one of
 #'
-#' 1,2. \code{X}, \code{s[X]}, \code{Y}, \code{s[Y]}, \code{rho}
+#' \code{1} or \code{2}: \code{X}, \code{s[X]}, \code{Y}, \code{s[Y]},
+#' \code{rho}; where \code{rho} is the error correlation between
+#' \code{X} and \code{Y}; or
 #'
-#' where \code{rho} is the error correlation between \code{X} and
-#' \code{Y}, or
-#'
-#' 3. \code{X/Z}, \code{s[X/Z]}, \code{Y/Z}, \code{s[Y/Z]},
-#' \code{X/Y}, \code{s[X/Y]} for which the error correlations are
+#' \code{3}: \code{X/Z}, \code{s[X/Z]}, \code{Y/Z}, \code{s[Y/Z]},
+#' \code{X/Y}, \code{s[X/Y]}; for which the error correlations are
 #' automatically computed from the redundancy of the three ratios.
 #'
 #' @param ... optional arguments
+#' 
 #' @return a five-column table that can be used as input for
 #'     \code{\link{york}}-regression.
+#' 
 #' @examples
 #' f <- system.file("RbSr1.csv",package="IsoplotR")
 #' dat <- read.csv(f)
 #' yorkdat <- data2york(dat)
 #' fit <- york(yorkdat)
+#' 
 #' @seealso \code{\link{york}}
 #' @rdname data2york
 #' @export
@@ -208,23 +216,27 @@ data2york.default <- function(x,format=1,...){
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
+
 #' @param option returns one of
 #'
 #' \enumerate{
 #'
-#' \item Wetherill concordia ratios: \code{X=7/5}, \code{sX=s[7/5]},
-#'     \code{Y=6/8}, \code{sY=s[6/8]}, \code{rXY}.
+#' \item Wetherill concordia ratios: \code{X=07/35}, \code{sX=s[07/35]},
+#'     \code{Y=06/38}, \code{sY=s[06/38]}, \code{rXY}.
 #'
-#' \item Tera-Wasserburg ratios: \code{X=8/6}, \code{sX=s[8/6]},
-#'     \code{Y=7/6}, \code{sY=s[7/6]}, \code{rho=rXY}.
+#' \item Tera-Wasserburg ratios: \code{X=08/06}, \code{sX=s[08/06]},
+#'     \code{Y=07/06}, \code{sY=s[07/06]}, \code{rho=rXY}.
 #'
-#' \item \code{X=4/6}, \code{sX=s[4/6]}, \code{Y=8/6},
-#'     \code{sY=s[8/6]}, \code{rho=rXY} (only valid if \code{format >
-#'     3}).
+#' \item \code{X=04/06}, \code{sX=s[04/06]}, \code{Y=08/06},
+#'     \code{sY=s[08/06]}, \code{rho=rXY} (only valid if \code{format=4,5,6}).
 #'
-#' \item \code{X=4/7}, \code{sX=s[4/7]}, \code{Y=5/7},
-#'     \code{sY=s[5/7]}, \code{rho=rXY} (only valid if \code{format >
-#'     3}).
+#' \item \code{X=04/07}, \code{sX=s[04/07]}, \code{Y=05/07},
+#'     \code{sY=s[05/07]}, \code{rho=rXY} (only valid if
+#'     \code{format=4,5,6}).
+#'
+#' \item \code{X=08/32}, \code{sX=s[08/32]}, \code{Y=06/38},
+#'     \code{sY=s[06/38]}, \code{rho=rXY} (only valid if
+#'     \code{format=8,9}). 
 #' 
 #' }
 #'
@@ -234,10 +246,10 @@ data2york.UPb <- function(x,option=1,...){
     ns <- length(x)
     out <- matrix(0,ns,5)
     colnames(out) <- c('X','sX','Y','sY','rXY')
-    if (option==1 && x$format %in% c(1,3,4)){
+    if (option==1 && x$format %in% c(1,3,4,7)){
         out <- subset(x$x,select=c('Pb207U235','errPb207U235',
                                    'Pb206U238','errPb206U238','rhoXY'))
-    } else if (option==1 && x$format %in% c(2,5,6)){
+    } else if (option==1 && x$format %in% c(2,5,6,8)){
         for (i in 1:ns){
             samp <- wetherill(x,i=i)
             out[i,1] <- samp$x['Pb207U235']
@@ -246,10 +258,10 @@ data2york.UPb <- function(x,option=1,...){
             out[i,4] <- sqrt(samp$cov['Pb206U238','Pb206U238'])
             out[i,5] <- stats::cov2cor(samp$cov[1:2,1:2])[1,2]
         }
-    } else if (option==2 && x$format %in% c(2,5)){
+    } else if (option==2 && x$format %in% c(2,5,8)){
         out <- subset(x$x,select=c('U238Pb206','errU238Pb206',
                                    'Pb207Pb206','errPb207Pb206','rhoXY'))
-    } else if (option==2 && x$format %in% c(1,3,4,6)){
+    } else if (option==2 && x$format %in% c(1,3,4,6,7)){
         for (i in 1:ns){
             samp <- tera.wasserburg(x,i=i)
             out[i,1] <- samp$x['U238Pb206']
@@ -340,7 +352,21 @@ data2york.UPb <- function(x,option=1,...){
         err <- errorprop(J11,J12,J21,J22,E11,E22,E12)
         out[,2] <- sqrt(err[,1])
         out[,4] <- sqrt(err[,2])
-        out[,5] <- err[,3]/(out[,2]*out[,4])        
+        out[,5] <- err[,3]/(out[,2]*out[,4])
+    } else if (option==5 && x$format==7){
+        out <- subset(x$x,select=c('Pb206U238','errPb206U238',
+                                   'Pb208Th232','errPb208Th232','rhoYZ'))
+    } else if (option==5 && x$format==8){
+        for (i in 1:ns){
+            samp <- wetherill(x,i=i)
+            out[i,1] <- samp$x['Pb206U238']
+            out[i,2] <- sqrt(samp$cov['Pb206U238','Pb206U238'])
+            out[i,3] <- samp$x['Pb208Th232']
+            out[i,4] <- sqrt(samp$cov['Pb208Th232','Pb208Th232'])
+            out[i,5] <- stats::cov2cor(samp$cov[2:3,2:3])[1,2]
+        }
+    } else {
+        stop('Incompatible input format and concordia type.')
     }
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
@@ -416,6 +442,7 @@ data2york.PbPb <- function(x,inverse=TRUE,...){
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
+
 #' @param exterr If \code{TRUE}, propagates the external uncertainties
 #'     (e.g. decay constants) into the output errors.
 #' @rdname data2york
